<?php
/*
 Plugin Name: WP OS FLV
 Plugin URI: http://kahancreations.com/
 Description: Easy to integrate flv player.
 Author: Amit Sidhpura
 Version: 1.0.0
 Author URI: http://kahancreations.com/
 */

require_once('lib/getid3.php');
include_once('wposflv-widget.php');

class WPOSFLV {	
	
	// Options page name
	var $optionsPageName = "wp-os-flv";
	
	function __construct() {
		add_action('admin_menu', array($this, 'addMenuItem'));
		add_filter("attachment_fields_to_edit", array($this, "insertVideoPlayerButton"), 10, 2);
		add_filter("media_send_to_editor", array($this, "sendToEditor"));
		add_filter("plugin_action_links", array($this, "addConfigureLink"), 10, 2);
		add_action('wp_head', array($this, 'addHeaderCode'));
		add_shortcode('wposflv', array($this, 'insertPlayerCode'));
		add_action('widgets_init', create_function('', 'return register_widget("WPOSFLV_Widget");'));		
		register_activation_hook(__FILE__, array($this, 'activateWPOSFLV'));
		register_deactivation_hook(__FILE__, array($this, 'deactivateWPOSFLV'));
	}
	
	public function activateWPOSFLV() {
		add_option("wposflv-accentcolor", "#31b8e9");
		add_option("wposflv-allowFullScreen", "true");
		add_option("wposflv-allowScriptAccess", "always");
		add_option("wposflv-autoload", "on");
		add_option("wposflv-autoplay", "off");
		add_option("wposflv-btncolor", "#333333");
		add_option("wposflv-showtitle", "yes");
		add_option("wposflv-txtcolor", "#dddddd");
		add_option("wposflv-volume", "70");
	}
	
	public function deactivateWPOSFLV() {
		delete_option("wposflv-accentcolor");
		delete_option("wposflv-allowFullScreen");
		delete_option("wposflv-allowScriptAccess");
		delete_option("wposflv-autoload");
		delete_option("wposflv-autoplay");
		delete_option("wposflv-btncolor");
		delete_option("wposflv-showtitle");
		delete_option("wposflv-txtcolor");
		delete_option("wposflv-volume");
	}
	
	public function addConfigureLink($links, $file) {
		static $this_plugin;
		if (!$this_plugin) {
			$this_plugin = plugin_basename(__FILE__);
		}
		if ($file == $this_plugin) {
			$settings_link = '<a href="options-general.php?page=' . $this->optionsPageName . '">'.__('Settings').'</a>';
			array_unshift($links, $settings_link);
		}
		return $links;
	}
	
	public function addAdminScripts() {		
		wp_enqueue_script('farbtastic');
		wp_register_script('jquery-ui-slider', WP_PLUGIN_URL."/wp-os-flv/js/ui.slider.js", array('jquery-ui-core'));
		wp_enqueue_script('jquery-ui-slider');
		wp_register_script('wposflv-scripts', WP_PLUGIN_URL."/wp-os-flv/js/wposflv.js", array('jquery-ui-slider', 'farbtastic'));
		wp_enqueue_script('wposflv-scripts');
	}
	
	public function addAdminStyles() {
		wp_enqueue_style('farbtastic');
		wp_register_style('jquery-ui-themes', WP_PLUGIN_URL."/wp-os-flv/css/ui-themes/base/ui.all.css");
		wp_enqueue_style('jquery-ui-themes');
		wp_register_style('wposflv-styles', WP_PLUGIN_URL."/wp-os-flv/css/wposflv.css");
		wp_enqueue_style('wposflv-styles');
	}
	
	public function addMenuItem() {
		$page = add_options_page('WP OS FlV', 'WP OS FlV', 'manage_options', 'wp-os-flv', array($this, 'manageOptions'));		
		add_action('admin_init', array($this, 'registerSettings'));		
		add_action('admin_print_scripts-'.$page, array($this, "addAdminScripts"));
		add_action('admin_print_styles-'.$page, array($this, "addAdminStyles"));
	}
	
	public function insertVideoPlayerButton($form_fields, $post) {
		global $wp_version;
		$file = wp_get_attachment_url($post->ID);
		if ($post->post_mime_type == 'video/x-flv') {
			$form_fields["url"]["html"] .= "<button type='button' class='button urlvideoplayer video-player-".$post->ID."' value='[wposflv src=".attribute_escape($file)."]' title='[wposflv src=".attribute_escape($file)."]'>Video Player</button>";			
			if (version_compare($wp_version, "2.7", "<")) {
				$form_fields["url"]["html"] .= "<script type='text/javascript'>
				jQuery('button.video-player-".$post->ID."').bind('click', function(){jQuery(this).siblings('input').val(this.value);});
				</script>\n";
			}
		}		
		return $form_fields;
	}
	
	public function sendToEditor($html) {
		if (preg_match("/<a ([^=]+=['\"][^\"']+['\"] )*href=['\"](\[wposflv src=([^\"']+\.flv)])['\"]( [^=]+=['\"][^\"']+['\"])*>([^<]*)<\/a>/i", $html, $matches)) {
			$html = $matches[2];
		}
		return $html;
	}
	
	public function manageOptions() {
		include "wposflv-admin-view.php";
	}
	
	public function registerSettings() {
		register_setting('wposflv-settings-group', 'wposflv-btncolor');
		register_setting('wposflv-settings-group', 'wposflv-accentcolor');
		register_setting('wposflv-settings-group', 'wposflv-txtcolor');
		register_setting('wposflv-settings-group', 'wposflv-volume');
		register_setting('wposflv-settings-group', 'wposflv-autoload');
		register_setting('wposflv-settings-group', 'wposflv-autoplay');
		register_setting('wposflv-settings-group', 'wposflv-showtitle');
		register_setting('wposflv-settings-group', 'wposflv-allowFullScreen');
		register_setting('wposflv-settings-group', 'wposflv-allowScriptAccess');
	}
	
	public function addHeaderCode() {
		if(strpos($_SERVER['HTTP_USER_AGENT'], 'MSIE'))
			echo "<script src='".WP_PLUGIN_URL."/wp-os-flv/js/AC_RunActiveContent.js' language='javascript'></script>";
		else
			echo "<script charset='ISO-8859-1' src='".WP_PLUGIN_URL."/wp-os-flv/js/rac.js' language='javascript'></script>";
	}
	
	public function insertPlayerCode($atts) {
		$path = WP_CONTENT_DIR.'/'.trim(end(preg_split("/wp-content/", $atts['src'])), "\\/");
		
		//Calculate dimentions
		if(file_exists($path))
			$dimension = $this->getflvsize($path);
		
		//Attributes
		$src = $atts['src'];
		$vTitle = $atts['title'];
		$width = $atts['width'] == ''?$dimension['width']:$atts['width'];
		$height = $atts['height'] == ''?$dimension['height']:$atts['height'];
		$previewimage = $atts['previewimage'];
		
		//Options
		$btncolor = str_replace('#', '', get_option('wposflv-btncolor'));
		$accentcolor = str_replace('#', '', get_option('wposflv-accentcolor'));
		$txtcolor = str_replace('#', '', get_option('wposflv-txtcolor'));
		$volume = get_option('wposflv-volume');
		$autoload = get_option('wposflv-autoload');
		$autoplay = get_option('wposflv-autoplay');
		$showtitle = get_option('wposflv-showtitle');
		$allowFullScreen = get_option('wposflv-allowFullScreen');
		$allowScriptAccess = get_option('wposflv-allowScriptAccess');
		
		ob_start();
		include "wposflv-client-view.php";
		$output = ob_get_contents();
		ob_end_clean();
		return $output;
	}
	
	public function getflvsize($flv){
		$getID3 = new getID3;
		$fileinfo = $getID3->analyze($flv);
		if(!($fileinfo['meta']['onMetaData']['width'] && $fileinfo['meta']['onMetaData']['height']))
			return false;
		$width = $fileinfo['meta']['onMetaData']['width'];
		$height = $fileinfo['meta']['onMetaData']['height'];
		return array('width' => $width, 'height'=> $height);
	}
}

$objWPOSFLV = new WPOSFLV();

?>